@@ -25,7 +25,7 @@
 /* Boston, MA  02110-1301  USA					*/
 /****************************************************************/
 
-#define _BSD_SOURCE
+#define _DEFAULT_SOURCE
 
 #include <config.h>
 
