@@ -1,7 +1,7 @@
 /****************************************************************/
 /* jamcam.c - Gphoto2 library for the KBGear JamCam v2 and v3   */
 /*                                                              */
-/* Copyright  2001 Chris Pinkham                             */
+/* Copyright 2001 Chris Pinkham                                 */
 /*                                                              */
 /* Author: Chris Pinkham <cpinkham@infi.net>                    */
 /*                                                              */
@@ -19,8 +19,8 @@
 /*                                                              */
 /* You should have received a copy of the GNU Library General   */
 /* Public License along with this library; if not, write to the */
-/* Free Software Foundation, Inc., 59 Temple Place - Suite 330, */
-/* Boston, MA 02111-1307, USA.                                  */
+/* Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,*/
+/* Boston, MA  02110-1301  USA					*/
 /****************************************************************/
 
 #include "config.h"
@@ -218,9 +218,10 @@ static int get_file_func (CameraFilesystem *fs, const char *folder,
 
 		size = strlen( ppm ) + ( height * width * 3 );
 
-		gp_bayer_decode(raw, width, height, ptr, BAYER_TILE_GBRG );
+		gp_bayer_decode((unsigned char *)raw, width, height,
+				(unsigned char *)ptr, BAYER_TILE_GBRG );
 		gp_gamma_fill_table( gtable, 0.5 );
-		gp_gamma_correct_single( gtable, ptr, height * width );
+		gp_gamma_correct_single( gtable, (unsigned char *)ptr, height * width );
 
 		CHECK_free (gp_file_set_mime_type (file, GP_MIME_PPM));
 		CHECK_free (gp_file_append (file, ppm, size));
@@ -241,10 +242,10 @@ static int get_file_func (CameraFilesystem *fs, const char *folder,
 
 		size = strlen( ppm ) + ( jc_file->width * jc_file->height * 3 );
 
-		gp_bayer_decode( raw, jc_file->width, jc_file->height, ptr,
-			BAYER_TILE_GBRG );
+		gp_bayer_decode((unsigned char *)raw, jc_file->width, jc_file->height,
+				(unsigned char *)ptr, BAYER_TILE_GBRG );
 		gp_gamma_fill_table( gtable, 0.5 );
-		gp_gamma_correct_single( gtable, ptr, jc_file->width * jc_file->height );
+		gp_gamma_correct_single( gtable, (unsigned char *)ptr, jc_file->width * jc_file->height );
 
 		CHECK_free (gp_file_set_mime_type (file, GP_MIME_PPM));
 		CHECK_free (gp_file_append (file, ppm, size));
