@@ -1,6 +1,6 @@
 /*
     pkTriggerCord
-    Copyright (C) 2011-2017 Andras Salamon <andras.salamon@melda.info>
+    Copyright (C) 2011-2018 Andras Salamon <andras.salamon@melda.info>
     Remote control of Pentax DSLR cameras.
 
     Support for K200D added by Jens Dreyer <jens.dreyer@udo.edu> 04/2011
@@ -189,8 +189,9 @@ typedef enum {
 /* a different write_args function needs to be done with slightly changed */
 /* command sequence. Original function was ipslr_write_args(). */
 
-int pslr_get_buffer_status(pslr_handle_t *h, uint32_t *x, uint32_t *y) {
-    ipslr_handle_t *p = (ipslr_handle_t *) h;
+static
+int pslr_get_buffer_status(ipslr_handle_t *p, uint32_t *x, uint32_t *y) {
+    //ipslr_handle_t *p = (ipslr_handle_t *) h;
     DPRINT("[C]\t\tipslr_get_buffer_status()\n");
     uint8_t buf[8];
     int n;
@@ -483,10 +484,6 @@ int pslr_get_status(pslr_handle_t h, pslr_status *ps) {
     memset( ps, 0, sizeof( pslr_status ));
     CHECK(ipslr_status_full(p, &p->status));
     memcpy(ps, &p->status, sizeof (pslr_status));
-
-//    uint32_t x, y;
-//    pslr_get_buffer_status(h, &x, &y);
-
     return PSLR_OK;
 }
 
@@ -500,6 +497,7 @@ char *format_rational( pslr_rational_t rational, char * fmt ) {
     return ret;
 }
 
+static
 char *get_white_balance_single_adjust_str( uint32_t adjust, char negativeChar, char positiveChar ) {
     char *ret = malloc(4);
     if ( adjust < 7 ) {
@@ -512,6 +510,7 @@ char *get_white_balance_single_adjust_str( uint32_t adjust, char negativeChar, c
     return ret;
 }
 
+static
 char *get_white_balance_adjust_str( uint32_t adjust_mg, uint32_t adjust_ba ) {
     char *ret = malloc(8);
     if ( adjust_mg != 7 || adjust_ba != 7 ) {
@@ -522,6 +521,17 @@ char *get_white_balance_adjust_str( uint32_t adjust_mg, uint32_t adjust_ba ) {
     return ret;
 }
 
+char *pslr_get_af_name(pslr_handle_t h, uint32_t af_point) {
+    ipslr_handle_t *p = (ipslr_handle_t *) h;
+    if (p->model->af_point_num==11) {
+        return get_pslr_af11_point_str(af_point);
+    } else {
+        char *raw = malloc(11);
+        sprintf(raw, "%d", af_point);
+        return raw;
+    }
+}
+
 char *collect_status_info( pslr_handle_t h, pslr_status status ) {
     char *strbuffer = malloc(8192);
     sprintf(strbuffer,"%-32s: %d\n", "current iso", status.current_iso);
@@ -548,16 +558,16 @@ char *collect_status_info( pslr_handle_t h, pslr_status status ) {
     sprintf(strbuffer+strlen(strbuffer),"%-32s: %s\n", "raw format", get_pslr_raw_format_str(status.raw_format));
     sprintf(strbuffer+strlen(strbuffer),"%-32s: %d\n", "light meter flags", status.light_meter_flags);
     sprintf(strbuffer+strlen(strbuffer),"%-32s: %s\n", "ec", format_rational( status.ec, "%.2f" ) );
-    sprintf(strbuffer+strlen(strbuffer),"%-32s: %s\n", "custom ev steps", get_pslr_custom_ev_steps_str(status.custom_ev_steps));
-    sprintf(strbuffer+strlen(strbuffer),"%-32s: %d\n", "custom sensitivity steps", status.custom_sensitivity_steps);
+    sprintf(strbuffer+strlen(strbuffer),"%-32s: %s EV steps\n", "custom ev steps", get_pslr_custom_ev_steps_str(status.custom_ev_steps));
+    sprintf(strbuffer+strlen(strbuffer),"%-32s: %s EV steps\n", "custom sensitivity steps", get_pslr_custom_sensitivity_steps_str(status.custom_sensitivity_steps));
     sprintf(strbuffer+strlen(strbuffer),"%-32s: %d\n", "exposure mode", status.exposure_mode);
     sprintf(strbuffer+strlen(strbuffer),"%-32s: %s\n", "scene mode", get_pslr_scene_mode_str(status.scene_mode));
     sprintf(strbuffer+strlen(strbuffer),"%-32s: %d\n", "user mode flag", status.user_mode_flag);
     sprintf(strbuffer+strlen(strbuffer),"%-32s: %s\n", "ae metering mode", get_pslr_ae_metering_str(status.ae_metering_mode));
     sprintf(strbuffer+strlen(strbuffer),"%-32s: %s\n", "af mode", get_pslr_af_mode_str(status.af_mode));
     sprintf(strbuffer+strlen(strbuffer),"%-32s: %s\n", "af point select", get_pslr_af_point_sel_str(status.af_point_select));
-    sprintf(strbuffer+strlen(strbuffer),"%-32s: %d\n", "selected af point", status.selected_af_point);
-    sprintf(strbuffer+strlen(strbuffer),"%-32s: %d\n", "focused af point", status.focused_af_point);
+    sprintf(strbuffer+strlen(strbuffer),"%-32s: %s\n", "selected af point", pslr_get_af_name( h, status.selected_af_point));
+    sprintf(strbuffer+strlen(strbuffer),"%-32s: %s\n", "focused af point", pslr_get_af_name( h, status.focused_af_point));
     sprintf(strbuffer+strlen(strbuffer),"%-32s: %s\n", "drive mode", get_pslr_drive_mode_str(status.drive_mode));
     sprintf(strbuffer+strlen(strbuffer),"%-32s: %s\n", "auto bracket mode", status.auto_bracket_mode > 0 ? "on" : "off");
     sprintf(strbuffer+strlen(strbuffer),"%-32s: %d\n", "auto bracket picture count", status.auto_bracket_picture_count);
@@ -575,6 +585,55 @@ char *collect_status_info( pslr_handle_t h, pslr_status status ) {
     return strbuffer;
 }
 
+static
+char *get_hardwired_setting_bool_info( pslr_bool_setting setting) {
+    char *strbuffer = malloc(32+1);
+    sprintf(strbuffer,"%-32s", setting.pslr_setting_status == PSLR_SETTING_STATUS_HARDWIRED ? "\t[hardwired]" : "");
+    return strbuffer;
+}
+
+static
+char *get_special_setting_info( pslr_setting_status_t setting_status) {
+    char *strbuffer = malloc(32);
+    switch ( setting_status ) {
+        case PSLR_SETTING_STATUS_NA:
+            sprintf(strbuffer,"N/A");
+            break;
+        case PSLR_SETTING_STATUS_UNKNOWN:
+            sprintf(strbuffer,"Unknown");
+            break;
+        default:
+            return NULL;
+    }
+    return strbuffer;
+}
+
+static
+char *get_hardwired_setting_uint16_info( pslr_uint16_setting setting) {
+    char *strbuffer = malloc(32+1);
+    sprintf(strbuffer,"%-32s", setting.pslr_setting_status == PSLR_SETTING_STATUS_HARDWIRED ? "\t[hardwired]" : "");
+    return strbuffer;
+}
+
+char *collect_settings_info( pslr_handle_t h, pslr_settings settings ) {
+    char *strbuffer = malloc(8192);
+    sprintf(strbuffer,"%-32s: %-8s%s\n", "one push bracketing", get_special_setting_info(settings.one_push_bracketing.pslr_setting_status) ?: settings.one_push_bracketing.value ? "on" : "off", get_hardwired_setting_bool_info(settings.one_push_bracketing));
+    sprintf(strbuffer+strlen(strbuffer),"%-32s: %s%s\n", "bulb mode", get_special_setting_info(settings.bulb_mode_press_press.pslr_setting_status) ?: settings.bulb_mode_press_press.value ? "press-press" : "press-hold", get_hardwired_setting_bool_info(settings.bulb_mode_press_press));
+    sprintf(strbuffer+strlen(strbuffer),"%-32s: %-8s%s\n", "bulb timer", get_special_setting_info(settings.bulb_timer.pslr_setting_status) ?: settings.bulb_timer.value ? "on" : "off", get_hardwired_setting_bool_info(settings.bulb_timer));
+    char *bulb_timer_sec = malloc(32);
+    sprintf(bulb_timer_sec, "%d s", settings.bulb_timer_sec.value);
+    sprintf(strbuffer+strlen(strbuffer),"%-32s: %s%s\n", "bulb timer sec", get_special_setting_info(settings.bulb_timer_sec.pslr_setting_status) ?: bulb_timer_sec, get_hardwired_setting_uint16_info(settings.bulb_timer_sec));
+    sprintf(strbuffer+strlen(strbuffer),"%-32s: %-8s%s\n", "using aperture ring", get_special_setting_info(settings.using_aperture_ring.pslr_setting_status) ?: settings.using_aperture_ring.value ? "on" : "off", get_hardwired_setting_bool_info(settings.using_aperture_ring));
+    sprintf(strbuffer+strlen(strbuffer),"%-32s: %-8s%s\n", "shake reduction", get_special_setting_info(settings.shake_reduction.pslr_setting_status) ?: settings.shake_reduction.value ? "on" : "off", get_hardwired_setting_bool_info(settings.shake_reduction));
+    sprintf(strbuffer+strlen(strbuffer),"%-32s: %-8s%s\n", "astrotracer", get_special_setting_info(settings.astrotracer.pslr_setting_status) ?: settings.astrotracer.value ? "on" : "off", get_hardwired_setting_bool_info(settings.astrotracer));
+    char *astrotracer_timer_sec = malloc(32);
+    sprintf(astrotracer_timer_sec, "%d s", settings.astrotracer_timer_sec.value);
+    sprintf(strbuffer+strlen(strbuffer),"%-32s: %s%s\n", "astrotracer timer sec", get_special_setting_info(settings.astrotracer_timer_sec.pslr_setting_status) ?: astrotracer_timer_sec, get_hardwired_setting_uint16_info(settings.astrotracer_timer_sec));
+    sprintf(strbuffer+strlen(strbuffer),"%-32s: %-8s%s\n", "horizon correction", get_special_setting_info(settings.horizon_correction.pslr_setting_status) ?: settings.horizon_correction.value ? "on" : "off", get_hardwired_setting_bool_info(settings.horizon_correction));
+    return strbuffer;
+}
+
+
 int pslr_get_status_buffer(pslr_handle_t h, uint8_t *st_buf) {
     DPRINT("[C]\tpslr_get_status_buffer()\n");
     ipslr_handle_t *p = (ipslr_handle_t *) h;
@@ -585,6 +644,14 @@ int pslr_get_status_buffer(pslr_handle_t h, uint8_t *st_buf) {
     return PSLR_OK;
 }
 
+int pslr_get_settings_buffer(pslr_handle_t h, uint8_t *st_buf) {
+    DPRINT("[C]\tpslr_get_settings_buffer()\n");
+    ipslr_handle_t *p = (ipslr_handle_t *) h;
+    memset( st_buf, 0, SETTINGS_BUFFER_SIZE);
+    memcpy(st_buf, p->settings_buffer, SETTINGS_BUFFER_SIZE);
+    return PSLR_OK;
+}
+
 int pslr_get_buffer(pslr_handle_t h, int bufno, pslr_buffer_type type, int resolution,
                     uint8_t **ppData, uint32_t *pLen) {
     DPRINT("[C]\tpslr_get_buffer()\n");
@@ -601,9 +668,19 @@ int pslr_get_buffer(pslr_handle_t h, int bufno, pslr_buffer_type type, int resol
         return PSLR_NO_MEMORY;
     }
 
-    uint32_t bytes = pslr_buffer_read(h, buf, size);
-
-    if ( bytes != size ) {
+    uint32_t bufpos = 0;
+    while (true) {
+        uint32_t nextread = size - bufpos > 65536 ? 65536 : size - bufpos;
+        if (nextread == 0) {
+            break;
+        }
+        uint32_t bytes = pslr_buffer_read(h, buf+bufpos, nextread);
+        if (bytes == 0) {
+            break;
+        }
+        bufpos += bytes;
+    }
+    if ( bufpos != size ) {
         return PSLR_READ_ERROR;
     }
     pslr_buffer_close(h);
@@ -622,6 +699,7 @@ int pslr_set_progress_callback(pslr_handle_t h, pslr_progress_callback_t cb, uin
     return PSLR_OK;
 }
 
+static
 int ipslr_handle_command_x18( ipslr_handle_t *p, bool cmd9_wrap, int subcommand, int argnum,  ...) {
     DPRINT("[C]\t\tipslr_handle_command_x18(0x%x, %d)\n", subcommand, argnum);
     if ( cmd9_wrap ) {
@@ -738,6 +816,7 @@ int pslr_set_jpeg_stars(pslr_handle_t h, int jpeg_stars ) {
     return ipslr_handle_command_x18( p, true, X18_JPEG_STARS, 2, 1, hwqual, 0);
 }
 
+static
 int _get_user_jpeg_resolution( ipslr_model_info_t *model, int hwres ) {
     return model->jpeg_resolutions[hwres];
 }
@@ -747,6 +826,7 @@ int pslr_get_jpeg_resolution(pslr_handle_t h, int hwres) {
     return _get_user_jpeg_resolution( p->model, hwres );
 }
 
+static
 int _get_hw_jpeg_resolution( ipslr_model_info_t *model, int megapixel) {
     int resindex = 0;
     while ( resindex < MAX_RESOLUTION_SIZE && model->jpeg_resolutions[resindex] > megapixel ) {
@@ -816,7 +896,7 @@ int pslr_set_jpeg_saturation(pslr_handle_t h, int32_t saturation) {
 int pslr_set_image_format(pslr_handle_t h, pslr_image_format_t format) {
     DPRINT("[C]\tpslr_set_image_format(%X)\n", format);
     ipslr_handle_t *p = (ipslr_handle_t *) h;
-    if (format < 0 || format > PSLR_IMAGE_FORMAT_MAX) {
+    if (format >= PSLR_IMAGE_FORMAT_MAX) {
         return PSLR_PARAM;
     }
     return ipslr_handle_command_x18( p, true, X18_IMAGE_FORMAT, 2, 1, format, 0);
@@ -825,7 +905,7 @@ int pslr_set_image_format(pslr_handle_t h, pslr_image_format_t format) {
 int pslr_set_raw_format(pslr_handle_t h, pslr_raw_format_t format) {
     DPRINT("[C]\tpslr_set_raw_format(%X)\n", format);
     ipslr_handle_t *p = (ipslr_handle_t *) h;
-    if (format < 0 || format > PSLR_RAW_FORMAT_MAX) {
+    if (format >= PSLR_RAW_FORMAT_MAX) {
         return PSLR_PARAM;
     }
     return ipslr_handle_command_x18( p, true, X18_RAW_FORMAT, 2, 1, format, 0);
@@ -834,7 +914,7 @@ int pslr_set_raw_format(pslr_handle_t h, pslr_raw_format_t format) {
 int pslr_set_color_space(pslr_handle_t h, pslr_color_space_t color_space) {
     DPRINT("[C]\tpslr_set_raw_format(%X)\n", color_space);
     ipslr_handle_t *p = (ipslr_handle_t *) h;
-    if (color_space < 0 || color_space > PSLR_COLOR_SPACE_MAX) {
+    if (color_space >= PSLR_COLOR_SPACE_MAX) {
         return PSLR_PARAM;
     }
     return ipslr_handle_command_x18( p, true, X18_COLOR_SPACE, 1, color_space, 0, 0);
@@ -906,7 +986,7 @@ int pslr_set_exposure_mode(pslr_handle_t h, pslr_exposure_mode_t mode) {
     DPRINT("[C]\tpslr_set_exposure_mode(%X)\n", mode);
     ipslr_handle_t *p = (ipslr_handle_t *) h;
 
-    if (mode < 0 || mode >= PSLR_EXPOSURE_MODE_MAX) {
+    if (mode >= PSLR_EXPOSURE_MODE_MAX) {
         return PSLR_PARAM;
     }
     return ipslr_handle_command_x18( p, true, X18_EXPOSURE_MODE, 2, 1, mode, 0);
@@ -930,7 +1010,7 @@ int pslr_buffer_open(pslr_handle_t h, int bufno, pslr_buffer_type buftype, int b
     bufs = p->status.bufmask;
     DPRINT("\tp->status.bufmask = %x\n", p->status.bufmask);
 
-    if ( p->model->parser_function && (bufs & (1 << bufno)) == 0) {
+    if ( p->model->status_parser_function && (bufs & (1 << bufno)) == 0) {
         // do not check this for limited support cameras
         DPRINT("\tNo buffer data (%d)\n", bufno);
         return PSLR_READ_ERROR;
@@ -1068,9 +1148,9 @@ int pslr_get_model_max_jpeg_stars(pslr_handle_t h) {
     return p->model->max_jpeg_stars;
 }
 
-int pslr_get_model_buffer_size(pslr_handle_t h) {
+int pslr_get_model_status_buffer_size(pslr_handle_t h) {
     ipslr_handle_t *p = (ipslr_handle_t *) h;
-    return p->model->buffer_size;
+    return p->model->status_buffer_size;
 }
 
 int pslr_get_model_jpeg_property_levels(pslr_handle_t h) {
@@ -1085,7 +1165,7 @@ int *pslr_get_model_jpeg_resolutions(pslr_handle_t h) {
 
 bool pslr_get_model_only_limited(pslr_handle_t h) {
     ipslr_handle_t *p = (ipslr_handle_t *) h;
-    return p->model->buffer_size == 0 && !p->model->parser_function;
+    return p->model->status_buffer_size == 0 && !p->model->status_parser_function;
 }
 
 bool pslr_get_model_has_jpeg_hue(pslr_handle_t h) {
@@ -1133,6 +1213,25 @@ int pslr_get_model_af_point_num(pslr_handle_t h) {
     return p->model->af_point_num;
 }
 
+bool pslr_get_model_old_bulb_mode(pslr_handle_t h) {
+    ipslr_handle_t *p = (ipslr_handle_t *) h;
+    return p->model->old_bulb_mode;
+}
+
+bool pslr_get_model_bufmask_single(pslr_handle_t h) {
+    ipslr_handle_t *p = (ipslr_handle_t *) h;
+    return p->model->bufmask_single;
+}
+
+bool pslr_get_model_has_settings_parser(pslr_handle_t h) {
+    ipslr_handle_t *p = (ipslr_handle_t *) h;
+    char cameraid[10];
+    sprintf(cameraid, "0x%0x", p->model->id);
+    int def_num;
+    setting_file_process(cameraid, &def_num);
+    return def_num>0;
+}
+
 const char *pslr_camera_name(pslr_handle_t h) {
     DPRINT("[C]\tpslr_camera_name()\n");
     ipslr_handle_t *p = (ipslr_handle_t *) h;
@@ -1158,8 +1257,6 @@ pslr_buffer_type pslr_get_jpeg_buffer_type(pslr_handle_t h, int jpeg_stars) {
     return 2 + get_hw_jpeg_quality( p->model, jpeg_stars );
 }
 
-/* ----------------------------------------------------------------------- */
-
 static int ipslr_set_mode(ipslr_handle_t *p, uint32_t mode) {
     DPRINT("[C]\t\tipslr_set_mode(0x%x)\n", mode);
     CHECK(ipslr_write_args(p, 1, mode));
@@ -1216,7 +1313,7 @@ static int ipslr_status_full(ipslr_handle_t *p, pslr_status *status) {
     CHECK(command(p->fd, 0, 8, 0));
     n = get_result(p->fd);
     DPRINT("\tread %d bytes\n", n);
-    int expected_bufsize = p->model != NULL ? p->model->buffer_size : 0;
+    int expected_bufsize = p->model != NULL ? p->model->status_buffer_size : 0;
     if ( p->model == NULL ) {
         DPRINT("\tp model null\n");
     }
@@ -1224,7 +1321,7 @@ static int ipslr_status_full(ipslr_handle_t *p, pslr_status *status) {
 
     CHECK(read_result(p->fd, p->status_buffer, n > MAX_STATUS_BUF_SIZE ? MAX_STATUS_BUF_SIZE: n));
 
-    if ( expected_bufsize == 0 || !p->model->parser_function ) {
+    if ( expected_bufsize == 0 || !p->model->status_parser_function ) {
         // limited support only
         return PSLR_OK;
     } else if ( expected_bufsize > 0 && expected_bufsize != n ) {
@@ -1232,10 +1329,20 @@ static int ipslr_status_full(ipslr_handle_t *p, pslr_status *status) {
         return PSLR_READ_ERROR;
     } else {
         // everything OK
-        (*p->model->parser_function)(p, status);
+        (*p->model->status_parser_function)(p, status);
         if ( p->model->need_exposure_mode_conversion ) {
             status->exposure_mode = exposure_mode_conversion( status->exposure_mode );
         }
+        if ( p->model->bufmask_command ) {
+            uint32_t x, y;
+            int ret;
+
+            ret = pslr_get_buffer_status(p, &x, &y);
+            if (ret != PSLR_OK) {
+                return ret;
+            }
+            status->bufmask = x;
+        }
         return PSLR_OK;
     }
 }
@@ -1468,20 +1575,66 @@ int pslr_write_setting(pslr_handle_t *h, int offset, uint32_t value) {
     return PSLR_OK;
 }
 
-int pslr_read_settings(pslr_handle_t *h, int offset, int length, uint8_t *buf) {
-    int index=offset;
+int pslr_write_setting_by_name(pslr_handle_t *h, char *name, uint32_t value) {
+    ipslr_handle_t *p = (ipslr_handle_t *) h;
+    int def_num;
+    char cameraid[10];
+    sprintf(cameraid, "0x%0x", p->model->id);
+    //    printf("cameraid: %s\n", cameraid);
+    pslr_setting_def_t *defs = setting_file_process(cameraid, &def_num);
+    pslr_setting_def_t *setting_def = find_setting_by_name(defs, def_num, name);
+    if (setting_def != NULL) {
+        if (strcmp(setting_def->type,"boolean") == 0) {
+            pslr_write_setting(h, setting_def->address, value);
+        } else if (strcmp(setting_def->type, "uint16") == 0) {
+            pslr_write_setting(h, setting_def->address, value >> 8);
+            pslr_write_setting(h, setting_def->address+1, value & 0xff);
+        }
+    }
+    return PSLR_OK;
+}
+
+bool pslr_has_setting_by_name(pslr_handle_t *h, char *name) {
+    ipslr_handle_t *p = (ipslr_handle_t *) h;
+    int def_num;
+    char cameraid[10];
+    sprintf(cameraid, "0x%0x", p->model->id);
+    pslr_setting_def_t *defs = setting_file_process(cameraid, &def_num);
+    pslr_setting_def_t *setting_def = find_setting_by_name(defs, def_num, name);
+//    printf("%d %d\n", def_num, (setting_def != NULL));
+    return (setting_def != NULL);
+}
+
+
+int pslr_read_settings(pslr_handle_t *h) {
+    ipslr_handle_t *p = (ipslr_handle_t *) h;
+    int index=0;
     uint32_t value;
     int ret;
-    while (index<offset+length) {
+    while (index<SETTINGS_BUFFER_SIZE) {
         if ( (ret = pslr_read_setting(h, index, &value)) != PSLR_OK ) {
             return ret;
         }
-        buf[index] = value;
+        p->settings_buffer[index] = value;
         ++index;
     }
     return PSLR_OK;
 }
 
+int pslr_get_settings_json(pslr_handle_t h, pslr_settings *ps) {
+    DPRINT("[C]\tpslr_get_settings_json()\n");
+    ipslr_handle_t *p = (ipslr_handle_t *) h;
+    memset( ps, 0, sizeof( pslr_settings ));
+    CHECK(pslr_read_settings(h));
+    char cameraid[20];
+    sprintf(cameraid, "0x%05x", p->id);
+    DPRINT("cameraid:%s\n", cameraid);
+    ipslr_settings_parser_json(cameraid, p, &p->settings);
+    memcpy(ps, &p->settings, sizeof (pslr_settings));
+    return PSLR_OK;
+}
+
+
 static int _ipslr_write_args(uint8_t cmd_2, ipslr_handle_t *p, int n, ...) {
     va_list ap;
     uint8_t cmd[8] = {0xf0, 0x4f, cmd_2, 0x00, 0x00, 0x00, 0x00, 0x00};
@@ -1547,8 +1700,6 @@ static int _ipslr_write_args(uint8_t cmd_2, ipslr_handle_t *p, int n, ...) {
     return PSLR_OK;
 }
 
-/* ----------------------------------------------------------------------- */
-
 static int command(FDTYPE fd, int a, int b, int c) {
     DPRINT("[C]\t\t\tcommand(fd=%x, %x, %x, %x)\n", fd, a, b, c);
     uint8_t cmd[8] = {0xf0, 0x24, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00};
@@ -1653,7 +1804,7 @@ static int read_result(FDTYPE fd, uint8_t *buf, uint32_t n) {
 
 char *copyright() {
     char *ret = malloc(sizeof(char)*1024);
-    sprintf(ret, "Copyright (C) 2011-2017 Andras Salamon\n\
+    sprintf(ret, "Copyright (C) 2011-2018 Andras Salamon\n\
 \n\
 Based on:\n\
 pslr-shoot (C) 2009 Ramiro Barreiro\n\
@@ -1661,9 +1812,6 @@ PK-Remote (C) 2008 Pontus Lidman \n\n");
     return ret;
 }
 
-/* -----------------------------------------------------------------------
- write_debug
------------------------------------------------------------------------ */
 void write_debug( const char* message, ... ) {
 
     // Be sure debug is really on as DPRINT doesn't know
