@@ -22,7 +22,7 @@
 /* Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,*/
 /* Boston, MA  02110-1301  USA					*/
 /****************************************************************/
-#define _BSD_SOURCE
+#define _DEFAULT_SOURCE
 
 #include "config.h"
 
@@ -192,7 +192,7 @@ camera_capture (Camera *camera, CameraCaptureType type,
 
 	/* Not all our cameras support capture */
 	gp_camera_get_abilities (camera, &a);
-	if (!a.operations & GP_OPERATION_CAPTURE_IMAGE)
+	if (!(a.operations & GP_OPERATION_CAPTURE_IMAGE))
 		return GP_ERROR_NOT_SUPPORTED;
 
 	if (cam_has_flash(camera->pl))
