@@ -1,5 +1,6 @@
 var NAVTREEINDEX4 =
 {
+"jpeg_8c.html#a30e48d4e0366699fcd210b93a4c6a4f8":[2,0,2,20,26],
 "jpeg_8c.html#a4aee2400e444196497aaf51b5bda674b":[2,0,2,20,17],
 "jpeg_8c.html#a5bec69a612f0edb89186ecbc9cc8647b":[2,0,2,20,6],
 "jpeg_8c.html#a621dd0efba334f3b4f8c76e131d18f1e":[2,0,2,20,22],
@@ -248,6 +249,5 @@ var NAVTREEINDEX4 =
 "struct__CameraStorageInformation.html#a54d368755af52b0b4991e5cd8e706271":[1,0,15,5],
 "struct__CameraStorageInformation.html#a7e1cdd21daa0d4d710a66d35a2cee25a":[1,0,15,9],
 "struct__CameraStorageInformation.html#a8b96dab747312da81a5b0702882b002b":[1,0,15,7],
-"struct__CameraStorageInformation.html#a8bd76351601c330356c8656cc0e580f1":[1,0,15,0],
-"struct__CameraStorageInformation.html#aedb405bbdd1d882040d14bbf983818e9":[1,0,15,8]
+"struct__CameraStorageInformation.html#a8bd76351601c330356c8656cc0e580f1":[1,0,15,0]
 };
